From 5b0ec694a638cdbca038a76ad4bcae6daf6b37d6 Mon Sep 17 00:00:00 2001
From: FireMasterK <20838718+FireMasterK@users.noreply.github.com>
Date: Tue, 22 Feb 2022 07:15:25 +0000
Subject: [PATCH] Add requested changes.
---
.../schabi/newpipe/extractor/stream/StreamExtractor.java | 4 ++--
.../extractor/services/DefaultStreamExtractorTest.java | 9 +++++++--
2 files changed, 9 insertions(+), 4 deletions(-)
diff --git a/extractor/src/test/java/org/schabi/newpipe/extractor/services/DefaultStreamExtractorTest.java b/extractor/src/test/java/org/schabi/newpipe/extractor/services/DefaultStreamExtractorTest.java
index 5f02d55a5..f8fb6e935 100644
--- a/extractor/src/test/java/org/schabi/newpipe/extractor/services/DefaultStreamExtractorTest.java
+++ b/extractor/src/test/java/org/schabi/newpipe/extractor/services/DefaultStreamExtractorTest.java
@@ -34,6 +34,7 @@ import static org.schabi.newpipe.extractor.ExtractorAsserts.assertEqualsOrderInd
import static org.schabi.newpipe.extractor.ExtractorAsserts.assertIsSecureUrl;
import static org.schabi.newpipe.extractor.ExtractorAsserts.assertIsValidUrl;
import static org.schabi.newpipe.extractor.services.DefaultTests.defaultTestListOfItems;
+import static org.schabi.newpipe.extractor.stream.StreamExtractor.UNKNOWN_SUBSCRIBER_COUNT;
/**
* Test for {@link StreamExtractor}
@@ -45,7 +46,7 @@ public abstract class DefaultStreamExtractorTest extends DefaultExtractorTest
diff --git a/extractor/src/main/java/org/schabi/newpipe/extractor/stream/StreamExtractor.java b/extractor/src/main/java/org/schabi/newpipe/extractor/stream/StreamExtractor.java
index c84a7a8fc..939b4f5a5 100644
--- a/extractor/src/main/java/org/schabi/newpipe/extractor/stream/StreamExtractor.java
+++ b/extractor/src/main/java/org/schabi/newpipe/extractor/stream/StreamExtractor.java
@@ -207,11 +207,11 @@ public abstract class StreamExtractor extends Extractor {
* The subscriber count of the uploader.
* If the subscriber count is not implemented, or is unavailable, return -1
.
*
* @return the subscriber count of the uploader or -1 if not available
* @throws ParsingException
*/
public long getUploaderSubscriberCount() throws ParsingException {
- return -1;
+ return UNKNOWN_SUBSCRIBER_COUNT;
}
/**
@@ -207,11 +207,11 @@ public abstract class StreamExtractor extends Extractor {
.
*
- * @return the subscriber count of the uploader or -1 if not available
+ * @return the subscriber count of the uploader or {@value UNKNOWN_SUBSCRIBER_COUNT} if not available
* @throws ParsingException
*/